<!DOCTYPE html>
<html>
  <head>
  </head>
  <body>
    <span class="firstobj">First!</span>
    <span class="secondobj">Second!</span>
    <span class="thirdobj">Third!</span>
    <span class="sessionobj">Session!</span>
  </body>
</html>
