
	<div class="main-product">

		<div class="crumbs">
			<ul><li class="crumb-nav"><a href="" class="crumb-link">Domov</a> &gt;</li> <li class="crumb-nav"><a href="" class="crumb-link">Priložnosti</a> &gt; </li><li class="crumb-nav"><a href="" class="crumb-link">Rojstni dan</a> &gt; </li><li class="product-nav"><span class="crumb"> Two dozen red roses </span></li></ul>
		</div>
		
		<h1 class="name">Two Dozen Red Roses</h1>

		<div class="product-gallery">

			<img src="/img/img_big.jpg" class="product-image" width="360" height="360"/>

			<div class="thumbs">

				<div class="thumb">
					<a href=""><img src="/img/img_thumb1.jpg" /></a>
				</div>
				<div class="thumb">
					<a href=""><img src="/img/img_thumb1.jpg" /></a>
				</div>
				<div class="thumb">
					<a href=""><img src="/img/img_thumb1.jpg" /></a>
				</div>
				<div class="thumb last">
					<a href=""><img src="/img/img_thumb1.jpg" /></a>
				</div>
				
			</div>

		</div> <!-- end product-gallery -->

		<div class="product-info">

			<p class="product-teaser">Surprise the one who makes you smile, or express season's greetings perfectly with this elegant bouquet of two dozen striking red roses. Order today and for a limited time, get a Free clear glass vase with purchase. This elegant arrangement is a truly thoughtful gift that shows how much you care. </p>

			<ul>
				<li><strong>Višina:</strong> 30cm</li>
				<li><strong>Teža:</strong> <span class="weight">0</span>&nbsp;kg.</li>
			</ul>

            <form action="/cart" method="post">

			<div class="product-attributes">

				<h3>Izberite različico</h3>

				<ul class="product-attributes-list">
<li class="product-attributes-item">
  <span class="product-attributes-title">Attribute</span>
  <ul>
    <li>
      <select class="product-attributes-name">
        <option class="product-attributes-values-item product-attributes-value">Value</option>
      </select>
    </li>
  </ul>
</li>
				</ul>

			</div>

			<div class="product-options">

				<h3>Izberite različico</h3>

				<ul class="product-options-list">
					<li class="product-options-item"><input type="radio" name="sku" value="" class="product-options-sku"/> <span class="product-options-name">6 roses with vase</span> - <span class="product-options-price">26,45 EUR</span></li>
					<li class="product-options-item"><input type="radio" /> 12 roses with vase - <span class="product-options-price">32,45 EUR</span></li>
					<li class="product-options-item"><input type="radio" /> 24 roses with vase - <span class="product-options-price">40,50 EUR</span></li>
					<li class="product-options-item"><input type="radio" /> 36 roses with vase - <span class="product-options-price">66,45 EUR</span></li>
				</ul>

				<input type="hidden" name="sku" class="sku" value="">
				<input type="submit" value="Dodaj v košarico" class="btn-cart" />

			</div>
          </form>

		</div> <!-- end product-info -->

		<div class="clear"></div>


		<div class="product-description">

			<p>Surprise the one who makes you smile, or express season's greetings perfectly with this elegant bouquet of two dozen striking red roses. Order today and for a limited time, get a Free clear glass vase with purchase. This elegant arrangement is a truly thoughtful gift that shows how much you care.</p>

			<ul>
				<li>Gorgeous bouquet of two dozen of our freshest roses</li>
				<li>Free ribbed clear glass Ginger Jar vase; measures 7.25"H</li>
				<li>Each lovely red rose will arrive in bud form and will bloom in a few days to ensure your roses last as long as possible</li>
				<li>Our expert growers pick every rose with care and at the peak of perfection</li>
				<li>To ensure your roses are fresh, this order is shipped overnight</li>
			</ul>

			<p>Send the roses and Free* clear vase or add more holiday smiles with:</p>

			<ul>
				<li>Our elegant Mercury glass Silver Swirl vase; measures 8.5"H x 4.25"W</li>
				<li>Our stylish Red Tapered glass vase; measures 9"H</li>
				<li>A classic clear glass vase; measures 9"H</li>
			</ul>

			<p>Make it a truly original holiday celebration with a festive gift combination.</p>
		
		</div>


	</div> <!-- end main -->
